@@ -67,6 +67,8 @@ new IotToKinesisFirehoseToS3(scope: Construct, id: string, props: IotToKinesisFi
 |existingBucketObj?|[`s3.IBucket`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.IBucket.html)|Existing instance of S3 Bucket object, providing both this and `bucketProps` will cause an error.|
 |bucketProps?|[`s3.BucketProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.BucketProps.html)|User provided props to override the default props for the S3 Bucket. If this is provided, then also providing bucketProps is an error. |
 |logGroupProps?|[`logs.LogGroupProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-logs.LogGroupProps.html)|User provided props to override the default props for for the CloudWatchLogs LogGroup.|
+|loggingBucketProps?|[`s3.BucketProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.BucketProps.html)|Optional user provided props to override the default props for the S3 Logging Bucket.|
+|logS3AccessLogs? | boolean|Whether to turn on Access Logging for the S3 bucket. Creates an S3 bucket with associated storage costs for the logs. Enabling Access Logging is a best practice. default - true|
 
 ## Pattern Properties
 
@@ -79,6 +81,7 @@ new IotToKinesisFirehoseToS3(scope: Construct, id: string, props: IotToKinesisFi
 |iotActionsRole|[`iam.Role`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-iam.Role.html)|Returns an instance of the iam.Role created by the construct for IoT Rule|
 |kinesisFirehoseRole|[`iam.Role`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-iam.Role.html)|Returns an instance of the iam.Role created by the construct for Kinesis Data Firehose delivery stream|
 |kinesisFirehoseLogGroup|[`logs.LogGroup`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-logs.LogGroup.html)|Returns an instance of the LogGroup created by the construct for Kinesis Data Firehose delivery stream|
+|s3BucketInterface|[`s3.IBucket`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.IBucket.html)|Returns an instance of s3.IBucket created by the construct|
 
 ## Default settings
 
@@ -129,24 +132,26 @@ import aws_cdk.aws_iot
 import aws_cdk.aws_kinesisfirehose
 import aws_cdk.aws_logs
 import aws_cdk.aws_s3
-import aws_cdk.core
+import constructs
 
 
 class IotToKinesisFirehoseToS3(
-    aws_cdk.core.Construct,
+    constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-iot-kinesisfirehose-s3.IotToKinesisFirehoseToS3",
 ):
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         iot_topic_rule_props: aws_cdk.aws_iot.CfnTopicRuleProps,
         bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
         existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
         kinesis_firehose_props: typing.Any = None,
+        logging_bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
         log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
+        log_s3_access_logs: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
@@ -155,7 +160,9 @@ class IotToKinesisFirehoseToS3(
         :param bucket_props: User provided props to override the default props for the S3 Bucket. Default: - Default props are used
         :param existing_bucket_obj: Existing instance of S3 Bucket object, providing both this and ``bucketProps`` will cause an error. Default: - None
         :param kinesis_firehose_props: Optional user provided props to override the default props. Default: - Default props are used
+        :param logging_bucket_props: Optional user provided props to override the default props for the S3 Logging Bucket. Default: - Default props are used
         :param log_group_props: User provided props to override the default props for the CloudWatchLogs LogGroup. Default: - Default props are used
+        :param log_s3_access_logs: Whether to turn on Access Logs for the S3 bucket with the associated storage costs. Enabling Access Logging is a best practice. Default: - true
 
         :access: public
         :since: 0.8.0
@@ -166,10 +173,12 @@ class IotToKinesisFirehoseToS3(
             bucket_props=bucket_props,
             existing_bucket_obj=existing_bucket_obj,
             kinesis_firehose_props=kinesis_firehose_props,
+            logging_bucket_props=logging_bucket_props,
             log_group_props=log_group_props,
+            log_s3_access_logs=log_s3_access_logs,
         )
 
-        jsii.create(IotToKinesisFirehoseToS3, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="iotActionsRole")
@@ -196,6 +205,11 @@ class IotToKinesisFirehoseToS3(
     def kinesis_firehose_role(self) -> aws_cdk.aws_iam.Role:
         return typing.cast(aws_cdk.aws_iam.Role, jsii.get(self, "kinesisFirehoseRole"))
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="s3BucketInterface")
+    def s3_bucket_interface(self) -> aws_cdk.aws_s3.IBucket:
+        return typing.cast(aws_cdk.aws_s3.IBucket, jsii.get(self, "s3BucketInterface"))
+
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="s3Bucket")
     def s3_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
@@ -215,7 +229,9 @@ class IotToKinesisFirehoseToS3(
         "bucket_props": "bucketProps",
         "existing_bucket_obj": "existingBucketObj",
         "kinesis_firehose_props": "kinesisFirehoseProps",
+        "logging_bucket_props": "loggingBucketProps",
         "log_group_props": "logGroupProps",
+        "log_s3_access_logs": "logS3AccessLogs",
     },
 )
 class IotToKinesisFirehoseToS3Props:
@@ -226,14 +242,18 @@ class IotToKinesisFirehoseToS3Props:
         bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
         existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
         kinesis_firehose_props: typing.Any = None,
+        logging_bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
         log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
+        log_s3_access_logs: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''
         :param iot_topic_rule_props: User provided CfnTopicRuleProps to override the defaults. Default: - Default props are used
         :param bucket_props: User provided props to override the default props for the S3 Bucket. Default: - Default props are used
         :param existing_bucket_obj: Existing instance of S3 Bucket object, providing both this and ``bucketProps`` will cause an error. Default: - None
         :param kinesis_firehose_props: Optional user provided props to override the default props. Default: - Default props are used
+        :param logging_bucket_props: Optional user provided props to override the default props for the S3 Logging Bucket. Default: - Default props are used
         :param log_group_props: User provided props to override the default props for the CloudWatchLogs LogGroup. Default: - Default props are used
+        :param log_s3_access_logs: Whether to turn on Access Logs for the S3 bucket with the associated storage costs. Enabling Access Logging is a best practice. Default: - true
 
         :summary: The properties for the IotToKinesisFirehoseToS3 Construct
         '''
@@ -241,6 +261,8 @@ class IotToKinesisFirehoseToS3Props:
             iot_topic_rule_props = aws_cdk.aws_iot.CfnTopicRuleProps(**iot_topic_rule_props)
         if isinstance(bucket_props, dict):
             bucket_props = aws_cdk.aws_s3.BucketProps(**bucket_props)
+        if isinstance(logging_bucket_props, dict):
+            logging_bucket_props = aws_cdk.aws_s3.BucketProps(**logging_bucket_props)
         if isinstance(log_group_props, dict):
             log_group_props = aws_cdk.aws_logs.LogGroupProps(**log_group_props)
         self._values: typing.Dict[str, typing.Any] = {
@@ -252,8 +274,12 @@ class IotToKinesisFirehoseToS3Props:
             self._values["existing_bucket_obj"] = existing_bucket_obj
         if kinesis_firehose_props is not None:
             self._values["kinesis_firehose_props"] = kinesis_firehose_props
+        if logging_bucket_props is not None:
+            self._values["logging_bucket_props"] = logging_bucket_props
         if log_group_props is not None:
             self._values["log_group_props"] = log_group_props
+        if log_s3_access_logs is not None:
+            self._values["log_s3_access_logs"] = log_s3_access_logs
 
     @builtins.property
     def iot_topic_rule_props(self) -> aws_cdk.aws_iot.CfnTopicRuleProps:
@@ -292,6 +318,15 @@ class IotToKinesisFirehoseToS3Props:
         result = self._values.get("kinesis_firehose_props")
         return typing.cast(typing.Any, result)
 
+    @builtins.property
+    def logging_bucket_props(self) -> typing.Optional[aws_cdk.aws_s3.BucketProps]:
+        '''Optional user provided props to override the default props for the S3 Logging Bucket.
+
+        :default: - Default props are used
+        '''
+        result = self._values.get("logging_bucket_props")
+        return typing.cast(typing.Optional[aws_cdk.aws_s3.BucketProps], result)
+
     @builtins.property
     def log_group_props(self) -> typing.Optional[aws_cdk.aws_logs.LogGroupProps]:
         '''User provided props to override the default props for the CloudWatchLogs LogGroup.
@@ -301,6 +336,17 @@ class IotToKinesisFirehoseToS3Props:
         result = self._values.get("log_group_props")
         return typing.cast(typing.Optional[aws_cdk.aws_logs.LogGroupProps], result)
 
+    @builtins.property
+    def log_s3_access_logs(self) -> typing.Optional[builtins.bool]:
+        '''Whether to turn on Access Logs for the S3 bucket with the associated storage costs.
+
+        Enabling Access Logging is a best practice.
+
+        :default: - true
+        '''
+        result = self._values.get("log_s3_access_logs")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
