@@ -8,21 +8,16 @@ import jsii
 import publication
 import typing_extensions
 
-import aws_cdk.aws_iam._jsii
-import aws_cdk.aws_iot._jsii
-import aws_cdk.aws_kinesisfirehose._jsii
-import aws_cdk.aws_logs._jsii
-import aws_cdk.aws_s3._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
 import aws_solutions_constructs.aws_kinesis_firehose_s3._jsii
 import aws_solutions_constructs.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-solutions-constructs/aws-iot-kinesisfirehose-s3",
-    "1.112.0",
+    "2.4.0",
     __name__[0:-6],
-    "aws-iot-kinesisfirehose-s3@1.112.0.jsii.tgz",
+    "aws-iot-kinesisfirehose-s3@2.4.0.jsii.tgz",
 )
 
 __all__ = [
